%define _buildid .13

%bcond_with  systemd

Summary:        Random number generator related utilities
Name:           rng-tools
Version:	5        
Release: 11%{?_buildid}%{?dist}
Group:          System Environment/Base
License:        GPLv2+
URL:            http://sourceforge.net/projects/gkernel/
BuildRoot:      %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
# Note, need to update this next release to point to the new upstream
# https://github.com/ricardon/rng-tools
Source0:        http://downloads.sourceforge.net/project/gkernel/rng-tools/5/rng-tools-%{version}.tar.gz
Source1:        rngd.service

# initscripts support
Source101:      rngd.init
Source102:      rngd.sysconfig

Patch0:		rng-tools-4-ignorefail.patch
Patch1:		rng-tools-man.patch
Patch2:		real-rdrand.patch
Patch3:		rng-tools-rngtest-man.patch
Patch4:		rng-tools-entropy-option.patch
Patch5:		rng-tools-entropy-count-man.patch
Patch6:		rngd-verbose-behavior.patch
Patch7:		rng-tools-init-entsource.patch
Patch8:		rng-tools-alt-entsource.patch

BuildRequires:  groff gettext automake libsysfs-devel
Obsoletes:      rng-utils <= 1:2.0-5

%if %{with systemd}
BuildRequires:  systemd-units
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
%else
Requires(post):   chkconfig
Requires(preun):  chkconfig, initscripts
Requires(postun): initscripts
%endif

%description
Hardware random number generation tools.

%prep
%setup -q

%patch0 -p1 -b .ignore
%patch1 -p1 -b .man
%patch2 -p1 -b .rdrand
%patch3 -p1 -b .rngtest
%patch4 -p1 -b .entropy
%patch5 -p1 -b .man2
%patch6 -p0 -b .verbose
%patch7 -p1 -b .entsource
%patch8 -p1 -b .altentsource

%build
./autogen.sh
%configure
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} install

%if %{without systemd}
mkdir -p %{buildroot}%{_initddir}
install -m 755 %{SOURCE101} %{buildroot}%{_initddir}/rngd
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -m 640 %{SOURCE102} %{buildroot}%{_sysconfdir}/sysconfig/rngd
%else
mkdir -p %{buildroot}%{_unitdir}
install -m 644 %{SOURCE1} %{buildroot}%{_unitdir}
%endif

%clean
rm -rf %{buildroot}

%post
%if %{without systemd}
if [ $1 -eq 1 ]; then
   /sbin/chkconfig --add rngd
fi
%else
%systemd_post rngd.service
%endif

%preun
%if %{without systemd}
if [ $1 -eq 0 ]; then
   /sbin/service rngd stop > /dev/null 2>&1
   /sbin/chkconfig --del rngd
fi
%else
%systemd_preun rngd.service
%endif

%postun
%if %{without systemd}
if [ $1 -ge 1 ]; then
   /sbin/service rngd condrestart > /dev/null 2>&1
fi
%else
%systemd_postun_with_restart rngd.service
%endif

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING NEWS README
%if %{without systemd}
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/sysconfig/rngd
%attr(0755,root,root) %{_initddir}/rngd
%else
%attr(0644,root,root) %{_unitdir}/rngd.service
%endif
%{_bindir}/rngtest
%{_sbindir}/rngd
%{_mandir}/man1/rngtest.1.*
%{_mandir}/man8/rngd.8.*

%changelog
* Wed Aug 2 2017 Amazon Linux AMI <amazon-linux-ami@amazon.com>
- import source package EL7/rng-tools-5-11.el7

* Wed May 31 2017 Neil Horman <nhorman@redhat.com> - 5.11
- Fix initializtion of alternate entropy sources (bz 1454731)

* Tue Apr 19 2017 Jerry Snitselaar <jsnitsel@redhat.com> - 5.10
- Check for whether there is available rng during init (bz 1421234)

* Tue Apr 11 2017 Neil Horman <nhorman@redhat.com> - 5.9
- Fixed verbose behavior (bz 1437044)

* Fri Nov 4 2016 Amazon Linux AMI <amazon-linux-ami@amazon.com>
- import source package EL7/rng-tools-5-8.el7

* Fri Nov 20 2015 Amazon Linux AMI <amazon-linux-ami@amazon.com>
- import source package EL7/rng-tools-5-7.el7

* Mon Aug 17 2015 Neil Horman <nhorman@redhat.com> - 5.8
- Fixed man page (bz 1254223)

* Mon Jun 08 2015 Neil Horman <nhorman@redhat.com> - 5.7
- Added entropy limit option (bz 1211406)

* Thu May 28 2015 Neil Horman <nhorman@redhat.com> - 5.6
- Updating spec file (bz 1225175)

* Thu May 28 2015 Neil Horman <nhorman@redhat.com> - 5.5
- Update rngtest man page (bz 1225175)

* Wed Apr 08 2015 Neil Horman <nhorman@redhat.com> - 5.4
- Use real rdrand instructions

* Fri Mar 13 2015 Amazon Linux AMI <amazon-linux-ami@amazon.com>
- import source package EL7/rng-tools-5-2.el7

* Tue Mar 10 2015 Neil Horman <nhorman@redhat.com> - 5.3
- Fixed man page (bz 1178871)

* Fri Aug 22 2014 Neil Horman <nhorman@redhat.com> - 5.2
- Uploaded new sources from new upstream repo (bz1087590)

* Thu Aug 21 2014 Neil Horman <nhorman@redhat.com> - 5.1
- Update to rng tools version 5 (bz1087590)

* Wed May 7 2014 Cristian Gafton <gafton@amazon.com>
- import source package RHEL7/rng-tools-4-5.el7

* Fri Feb 28 2014 Ben Cressey <bcressey@amazon.com>
- conditionalize systemd support

* Fri Jan 24 2014 Daniel Mach <dmach@redhat.com> - 4-5
- Mass rebuild 2014-01-24

* Fri Dec 27 2013 Daniel Mach <dmach@redhat.com> - 4-4
- Mass rebuild 2013-12-27

* Fri Dec 13 2013 Cristian Gafton <gafton@amazon.com>
- import source package RHEL7/rng-tools-4-3.3.el7

* Mon Nov 4 2013 Jay Fenlason <fenlason@redhat.com> 4-3.3
- Forward port the -ignorefail patch from RHEL-6
  Resolves: rhbz1020635

* Mon Sep 30 2013 Jay Fenlason <fenlason@redhat.com> - 4-3.1
- Do not override sbindir, because it breaks selinux labelling on rngd
  Resolves: rhbz1000308

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Sep 25 2012 Jaromir Capik <jcapik@redhat.com> - 4-2
- Migration to new systemd macros

* Mon Aug 6 2012 Jeff Garzik <jgarzik@redhat.com> - 4-1
- Update to release version 4.

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jan 12 2012 Jiri Popelka <jpopelka@redhat.com> - 3-4
- 2 patches from RHEL-6
- systemd service
- man page fixes
- modernize spec file

* Fri Dec 9 2011 Cristian Gafton <gafton@amazon.com>
- import source package RHEL6/rng-tools-2-13.el6_2

* Thu Dec 8 2011 Cristian Gafton <gafton@amazon.com>
- import source package RHEL6/rng-tools-2-10.el6

* Mon Nov 21 2011 Cristian Gafton <gafton@amazon.com>
- import source package RHEL6/rng-tools-2-8.el6_1.1

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec 2 2010 Cristian Gafton <gafton@amazon.com>
- import source package RHEL6/rng-tools-2-8.el6

* Fri Jul 9 2010 Cristian Gafton <gafton@amazon.com>
- import source package RHEL6/rng-tools-2-7.el6
- setup complete for package rng-tools

* Sat Jul  3 2010 Jeff Garzik <jgarzik@redhat.com> - 3-2
- comply with renaming guidelines, by Providing rng-utils = 1:2.0-4.2

* Sat Jul  3 2010 Jeff Garzik <jgarzik@redhat.com> - 3-1
- Update to release version 3.

* Fri Mar 26 2010 Jeff Garzik <jgarzik@redhat.com> - 2-3
- more minor updates for package review

* Thu Mar 25 2010 Jeff Garzik <jgarzik@redhat.com> - 2-2
- several minor updates for package review

* Wed Mar 24 2010 Jeff Garzik <jgarzik@redhat.com> - 2-1
- initial revision (as rng-tools)
